@@ -11,7 +11,7 @@ use URI;
 use URI::QueryParam;
 use URI::file;
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 has dsn => sub { _dsn_from_path(shift->_tempfile_path) };
 has max_connections => 5;
@@ -30,6 +30,8 @@ has options => sub {
   };
 };
 
+sub new { @_ > 1 ? shift->SUPER::new->from_string(@_) : shift->SUPER::new }
+
 sub db {
   my $self = shift;
 
@@ -65,8 +67,6 @@ sub from_string {
   return $self->dsn($dsn);
 }
 
-sub new { @_ > 1 ? shift->SUPER::new->from_string(@_) : shift->SUPER::new }
-
 sub _dequeue {
   my $self = shift;
   while (my $dbh = shift @{$self->{queue} || []}) { return $dbh if $dbh->ping }
@@ -126,8 +126,8 @@ Mojo::SQLite - A tiny Mojolicious wrapper for SQLite
   say $@ if $@;
 
   # Insert another row and return the generated id
-  $db->query('insert into names (name) values (?)', 'Daniel');
-  say $db->query('select last_insert_rowid() as id')->hash->{id};
+  say $db->query('insert into names (name) values (?)', 'Daniel')
+    ->last_insert_id;
 
   # Select one row at a time
   my $results = $db->query('select * from names');
@@ -365,6 +365,10 @@ Report any issues on the public bugtracker.
 
 Dan Book, C<dbook@cpan.org>
 
+=head1 CREDITS
+
+Sebastian Riedel, author of L<Mojo::Pg>, which this distribution is based on.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2015, Dan Book.
